@@ -27,6 +27,7 @@ from authres import SPFAuthenticationResult, DKIMAuthenticationResult, Authentic
 from authres.arc import ARCAuthenticationResult
 from authres.dmarc import DMARCAuthenticationResult
 from dkim import ARC, DKIM, arc_verify, dkim_verify, DKIMException, rfc822_parse
+from dns.exception import DNSException
 from pkg_resources import resource_filename  # Part of setuptools
 
 # Please accept my appologies for doing this
@@ -61,8 +62,8 @@ def check_psddmarc_list(psdname, dnsfunc=dns_query):
         psds = []
         for line in psd_file.readlines():
             sp = line.split(',')
-            if sp[1] == 'Active':
-                psds += sp[0]
+            if sp[1] == 'current':
+                psds.append(sp[0][1:])
         if psdname in psds:
             return True
         else:
